/***********************************************************************/
/*                                                                     */
/* RIGI Utilities --- Copyright (C) 1996-1999                          */
/*                    The Rigi Group, University of Victoria           */
/*                                                                     */
/* see the file license.terms for usage and copying policies           */
/*                                                                     */
/* Author: Johannes Martin (jmartin@csr.csc.uvic.ca)                   */
/*                                                                     */
/***********************************************************************/
#include <stdio.h>

#include "htmltupl.h"

HtmlRsfTuple::StringSet HtmlRsfTuple::anchors;
HtmlRsfTuple::StringSet HtmlRsfTuple::bookmarks;

const UniqueString HtmlRsfTuple::nodeurlString = UniqueString("nodeurl");

HtmlRsfTuple::HtmlRsfTuple(const UniqueString& elem0,
			   const UniqueString& elem1,
			   const UniqueString& elem2,
			   const UniqueString& elem3,
			   int line, int column,
			   const UniqueString& oFile,
			   int oline)
  : RsfTuple(elem0, elem1, elem2, elem3, line, column) {
  this->oFile = oFile;
  this->oLine = oLine;
  if (line == 0)
    htmlType = NoType;
  else if (isKeyword(bookmarks))
    htmlType = Bookmark;
  else if (isKeyword(anchors))
    htmlType = Anchor;
  else
    htmlType = NoType;
}

HtmlRsfTuple::HtmlRsfTuple(const RsfTuple& rsfTuple,
			   const UniqueString& oFile,
			   int oline)
  : RsfTuple(rsfTuple) {
  this->oFile = oFile;
  this->oLine = oLine;
  if (line == 0)
    htmlType = NoType;
  else if (isKeyword(bookmarks))
    htmlType = Bookmark;
  else if (isKeyword(anchors))
    htmlType = Anchor;
  else
    htmlType = NoType;
}

HtmlRsfTuple::HtmlRsfTuple(char *inputLine, unsigned long lineNo,
			   bool preserve4Tuple)
  : RsfTuple(inputLine, lineNo, preserve4Tuple) {
 if (line == 0)
   htmlType = NoType;
 else if (isKeyword(bookmarks))
   htmlType = Bookmark;
 else if (isKeyword(anchors))
   htmlType = Anchor;
 else
   htmlType = NoType;
}

bool HtmlRsfTuple::operator< (const HtmlRsfTuple& other) const {
  int result = rsf[3].string().compare(other.rsf[3].string());
  if (result < 0)
    return true;
  if (result > 0)
    return false;
  if (line < other.line)
    return true;
  if (line > other.line)
    return false;
  if (column < other.column)
    return true;
  if (column > other.column)
    return false;
  return RsfTuple::operator<(other);
}

bool HtmlRsfTuple::print(FILE *output, bool preserve4Tuple) const {
  bool rc = RsfTuple::print(output, preserve4Tuple);

  // If the tuple has a URL associated to it, print it
  if (htmlType == Bookmark) {
    fprintf(output, "%s\t", nodeurlString.chars());
    printElement(output, rsf[1]);
    fprintf(output, "\t%s#%d\n", oFile.chars(), oLine);
  }
  return rc;
}

void HtmlRsfTuple::addAnchorString(const UniqueString& s) {
  anchors.insert(s);
}

void HtmlRsfTuple::addBookmarkString(const UniqueString& s) {
  bookmarks.insert(s);
}
