/***********************************************************************/
/*                                                                     */
/* RIGI Utilities --- Copyright (C) 1996-1999                          */
/*                    The Rigi Group, University of Victoria           */
/*                                                                     */
/* see the file license.terms for usage and copying policies           */
/*                                                                     */
/* Author: Johannes Martin (jmartin@csr.csc.uvic.ca)                   */
/*                                                                     */
/***********************************************************************/
#ifndef __RSF2HTML_H__
#define __RSF2HTML_H__

#include "rsftuple.h"
#include "htmltupl.h"

extern int maxLines;
extern int tabSize;

template <class T> class ptrLess {
  typedef T* ptrT;
public:
  bool operator()(const ptrT& x, const ptrT& y) const {
    return *x < *y;
  }
};

template <class T, class Less> class ptrSet : public set<T*, Less> {
public:
  typedef set<T*, Less> superSet;
  typedef typename superSet::iterator superIter;

  class iterator : public superIter {
  public:
    iterator() : superIter() {
    }

    iterator(const superIter& init) : superIter(init) {
    }

    T& operator*() {
      return *superIter::operator*();
    }
  };
  typedef iterator const_iterator;

  void insert(T* x) {
    superSet::insert(x);
  }

  void insert(const T& x) {
    insert(new T(x));
  }

  superIter find(T& x) {
    return superSet::find(&x);
  }
};

typedef ptrSet<HtmlRsfTuple, ptrLess<HtmlRsfTuple> > htmlTupleSet;
typedef ptrSet<HtmlRsfTuple, ptrLess<RsfTuple> > rsfTupleSet;

int Htmlize(htmlTupleSet& tuples, bool segmented, bool preformatted);

#endif
